@@ -55,11 +55,8 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class DecryptTestCase extends Crypt_GPG_TestCase
+class DecryptTest extends Crypt_GPG_TestCase
 {
-    // string
-    // {{{ testDecrypt()
-
     /**
      * @group string
      */
@@ -98,9 +95,6 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptNoPassphrase()
-
     /**
      * @group string
      */
@@ -137,16 +131,13 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptKeyNotFoundException()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group string
      */
     public function testDecryptKeyNotFoundException()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         // was encrypted with missing-key@example.com
         // {{{ encrypted data
         $encryptedData = <<<TEXT
@@ -175,44 +166,35 @@ TEXT;
         $this->gpg->decrypt($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptNoDataException_invalid()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group string
      */
     public function testDecryptNoDataException_invalid()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $encryptedData = 'Invalid OpenPGP data.';
         $this->gpg->decrypt($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptNoDataException_empty()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group string
      */
     public function testDecryptNoDataException_empty()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $encryptedData = '';
         $this->gpg->decrypt($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptBadPassphraseException_missing()
-
     /**
-     * @expectedException Crypt_GPG_BadPassphraseException
-     *
      * @group string
      */
     public function testDecryptBadPassphraseException_missing()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+
         // encrypted with first-keypair@example.com
         // {{{ encrypted data
         $encryptedData = <<<TEXT
@@ -241,16 +223,13 @@ TEXT;
         $this->gpg->decrypt($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptBadPassphraseException_bad()
-
     /**
-     * @expectedException Crypt_GPG_BadPassphraseException
-     *
      * @group string
      */
     public function testDecryptBadPassphraseException_bad()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+
         // encrypted with first-keypair@example.com
         // {{{ encrypted data
         $encryptedData = <<<TEXT
@@ -280,9 +259,6 @@ TEXT;
         $this->gpg->decrypt($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptDual()
-
     /**
      * @group string
      */
@@ -340,9 +316,6 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptDualOnePassphrase()
-
     /**
      * @group string
      */
@@ -398,16 +371,13 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptDualNoPassphraseKeyMissing()
-
     /**
-     * @expectedException Crypt_GPG_BadPassphraseException
-     *
      * @group string
      */
     public function testDecryptDualNoPassphraseKeyMissing()
     {
+        $this->expectException('Crypt_GPG_BadPassphraseException');
+
         // encrypted with both first-keypair@example.com and
         // second-keypair@example.com
         // {{{ dual encrypted data
@@ -455,9 +425,6 @@ TEXT;
         $this->gpg->decrypt($encryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptSignedData()
-
     /**
      * @group string
      */
@@ -484,9 +451,6 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptFirstSubKey()
-
     /**
      * @group string
      */
@@ -525,9 +489,6 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptSecondSubKey()
-
     /**
      * @group string
      */
@@ -561,9 +522,6 @@ TEXT;
         $this->assertEquals($expectedDecryptedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptFile()
-
     /**
      * @group file
      */
@@ -581,9 +539,6 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptFileToString()
-
     /**
      * @group file
      */
@@ -599,9 +554,6 @@ TEXT;
         $this->assertEquals($expectedData, $decryptedData);
     }
 
-    // }}}
-    // {{{ testDecryptFileNoPassphrase()
-
     /**
      * @group file
      */
@@ -622,16 +574,13 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptFileFileException_input()
-
     /**
-     * @expectedException Crypt_GPG_FileException
-     *
      * @group file
      */
     public function testDecryptFileFileException_input()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // input file does not exist
         $inputFilename =
             $this->getDataFilename('testDecryptFileFileException_input.asc');
@@ -639,16 +588,13 @@ TEXT;
         $this->gpg->decryptFile($inputFilename);
     }
 
-    // }}}
-    // {{{ testDecryptFileFileException_output()
-
     /**
-     * @expectedException Crypt_GPG_FileException
-     *
      * @group file
      */
     public function testDecryptFileFileException_output()
     {
+        $this->expectException('Crypt_GPG_FileException');
+
         // input file is encrypted with first-keypair@example.com
         // output file does not exist
         $inputFilename  = $this->getDataFilename('testDecryptFile.asc');
@@ -659,16 +605,13 @@ TEXT;
         $this->gpg->decryptFile($inputFilename, $outputFilename);
     }
 
-    // }}}
-    // {{{ testDecryptFileKeyNotFoundException()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group file
      */
     public function testDecryptFileKeyNotFoundException()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         // file is encrypted with missing-key@example.com
         $inputFilename =
             $this->getDataFilename('testDecryptFileKeyNotFoundException.asc');
@@ -679,9 +622,6 @@ TEXT;
         $this->gpg->decryptFile($inputFilename, $outputFilename);
     }
 
-    // }}}
-    // {{{ testDecryptFileDual()
-
     /**
      * @group file
      */
@@ -706,9 +646,6 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptFileDualOnePassphrase()
-
     /**
      * @group file
      */
@@ -735,23 +672,17 @@ TEXT;
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
 
-    // }}}
-    // {{{ testDecryptFileNoDataException()
-
     /**
-     * @expectedException Crypt_GPG_NoDataException
-     *
      * @group file
      */
     public function testDecryptFileNoDataException()
     {
+        $this->expectException('Crypt_GPG_NoDataException');
+
         $filename = $this->getDataFilename('testFileEmpty.plain');
         $this->gpg->decryptFile($filename);
     }
 
-    // }}}
-    // {{{ testDecryptFileSignedData()
-
     /**
      * @group string
      */
@@ -770,8 +701,4 @@ TEXT;
         $md5Sum = $this->getMd5Sum($outputFilename);
         $this->assertEquals($expectedMd5Sum, $md5Sum);
     }
-
-    // }}}
 }
-
-?>
