@@ -55,10 +55,8 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class DeletePrivateKeyTestCase extends Crypt_GPG_TestCase
+class DeletePrivateKeyTest extends Crypt_GPG_TestCase
 {
-    // {{{ testDeletePrivateKey()
-
     /**
      * @group delete-private
      */
@@ -107,35 +105,25 @@ class DeletePrivateKeyTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedKeys, $keys);
     }
 
-    // }}}
-    // {{{ testDeletePrivateKeyNotFoundException()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group delete-private
      */
     public function testDeletePrivateKeyNotFoundException()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         $keyId = 'non-existent-key@example.com';
         $this->gpg->deletePrivateKey($keyId);
     }
 
-    // }}}
-    // {{{ testDeletePrivateKeyNotFoundException_public_only()
-
     /**
-     * @expectedException Crypt_GPG_KeyNotFoundException
-     *
      * @group delete-private
      */
     public function testDeletePrivateKeyNotFoundException_public_only()
     {
+        $this->expectException('Crypt_GPG_KeyNotFoundException');
+
         $keyId = 'public-only@example.com';
         $this->gpg->deletePrivateKey($keyId);
     }
-
-    // }}}
 }
-
-?>
