@@ -55,10 +55,8 @@ require_once 'TestCase.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class GetKeysTestCase extends Crypt_GPG_TestCase
+class GetKeysTest extends Crypt_GPG_TestCase
 {
-    // {{{ testGetKeys()
-
     /**
      * @group get-keys
      */
@@ -248,9 +246,6 @@ class GetKeysTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedKeys, $keys);
     }
 
-    // }}}
-    // {{{ testGetKeysWithKeyId()
-
     /**
      * @group get-keys
      */
@@ -297,9 +292,6 @@ class GetKeysTestCase extends Crypt_GPG_TestCase
         $this->assertEquals($expectedKeys, $keys);
     }
 
-    // }}}
-    // {{{ testGetKeysNone()
-
     /**
      * @group get-keys
      */
@@ -310,8 +302,4 @@ class GetKeysTestCase extends Crypt_GPG_TestCase
         $keys = $this->gpg->getKeys($keyId);
         $this->assertEquals($expectedKeys, $keys);
     }
-
-    // }}}
 }
-
-?>
