@@ -60,11 +60,8 @@ require_once 'Crypt/GPG/KeyGenerator.php';
  * @license   http://www.gnu.org/copyleft/lesser.html LGPL License 2.1
  * @link      http://pear.php.net/package/Crypt_GPG
  */
-class KeyGeneratorTestCase extends Crypt_GPG_TestCase
+class KeyGeneratorTest extends Crypt_GPG_TestCase
 {
-    // helper methods
-    // {{{ assertKeyEquals()
-
     protected function assertKeyEquals(
         Crypt_GPG_Key $key1,
         Crypt_GPG_Key $key2
@@ -171,20 +168,12 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-    // {{{ setUp()
-
-    public function setUp()
+    public function setUp(): void
     {
         parent::setUp();
         $this->generator = new Crypt_GPG_KeyGenerator($this->getOptions());
     }
 
-    // }}}
-
-    // mutators
-    // {{{ testSetExpirationDate_zero()
-
     /**
      * @group mutators
      */
@@ -193,17 +182,10 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $expectedDate = 0;
         $this->generator->setExpirationDate(0);
 
-        $this->assertAttributeEquals(
-            $expectedDate,
-            'expirationDate',
-            $this->generator,
-            'Setting expiration date to zero failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'expirationDate');
+        $this->assertSame($expectedDate, $value, 'Setting expiration date to zero failed.');
     }
 
-    // }}}
-    // {{{ testSetExpirationDate_integer()
-
     /**
      * @group mutators
      */
@@ -212,17 +194,10 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $expectedDate = 2000000000;
         $this->generator->setExpirationDate(2000000000);
 
-        $this->assertAttributeEquals(
-            $expectedDate,
-            'expirationDate',
-            $this->generator,
-            'Setting expiration date by integer failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'expirationDate');
+        $this->assertSame($expectedDate, $value, 'Setting expiration date by integer failed.');
     }
 
-    // }}}
-    // {{{ testSetExpirationDate_string()
-
     /**
      * @group mutators
      */
@@ -233,67 +208,52 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $expectedDate = 2000000000;
         $this->generator->setExpirationDate('2033-05-18T03:33:20');
 
-        $this->assertAttributeEquals(
-            $expectedDate,
-            'expirationDate',
-            $this->generator,
-            'Setting expiration date by string failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'expirationDate');
+        $this->assertSame($expectedDate, $value, 'Setting expiration date by string failed.');
     }
 
-    // }}}
-    // {{{ testSetExpirationDate_invalid_format()
-
     /**
      * @group mutators
-     * @expectedException InvalidArgumentException
      */
     public function testSetExpirationDate_invalid_format()
     {
+        $this->expectException('InvalidArgumentException');
+
         date_default_timezone_set('UTC');
 
         $this->generator->setExpirationDate('this is not a date');
     }
 
-    // }}}
-    // {{{ testSetExpirationDate_too_early_date()
-
     /**
      * @group mutators
-     * @expectedException InvalidArgumentException
      */
     public function testSetExpirationDate_too_early_date()
     {
+        $this->expectException('InvalidArgumentException');
+
         $this->generator->setExpirationDate(1301088055);
     }
 
-    // }}}
-    // {{{ testSetExpirationDate_today()
-
     /**
      * @group mutators
-     * @expectedException InvalidArgumentException
      */
     public function testSetExpirationDate_today()
     {
+        $this->expectException('InvalidArgumentException');
+
         $this->generator->setExpirationDate(time());
     }
 
-    // }}}
-    // {{{ testSetExpirationDate_too_late_date()
-
     /**
      * @group mutators
-     * @expectedException InvalidArgumentException
      */
     public function testSetExpirationDate_too_late_date()
     {
+        $this->expectException('InvalidArgumentException');
+
         $this->generator->setExpirationDate(2147483648);
     }
 
-    // }}}
-    // {{{ testSetPassphrase()
-
     /**
      * @group mutators
      */
@@ -302,17 +262,10 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $expectedPassphrase = 'test1';
         $this->generator->setPassphrase('test1');
 
-        $this->assertAttributeEquals(
-            $expectedPassphrase,
-            'passphrase',
-            $this->generator,
-            'Setting passphrase failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'passphrase');
+        $this->assertSame($expectedPassphrase, $value, 'Setting passphrase failed.');
     }
 
-    // }}}
-    // {{{ testSetKeyParams_algorithm()
-
     /**
      * @group mutators
      */
@@ -327,31 +280,16 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             Crypt_GPG_SubKey::ALGORITHM_ELGAMAL_ENC_SGN
         );
 
-        $this->assertAttributeEquals(
-            $expectedAlgorithm,
-            'keyAlgorithm',
-            $this->generator,
-            'Setting key algorithm failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keyAlgorithm');
+        $this->assertSame($expectedAlgorithm, $value, 'Setting key algorithm failed.');
 
-        $this->assertAttributeEquals(
-            $expectedSize,
-            'keySize',
-            $this->generator,
-            'Setting key algorithm changed key size.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keySize');
+        $this->assertSame($expectedSize, $value, 'Setting key algorithm changed key size.');
 
-        $this->assertAttributeEquals(
-            $expectedUsage,
-            'keyUsage',
-            $this->generator,
-            'Setting key algorithm changed key usage.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keyUsage');
+        $this->assertSame($expectedUsage, $value, 'Setting key algorithm changed key usage.');
     }
 
-    // }}}
-    // {{{ testSetKeyParams_algorithm_and_size()
-
     /**
      * @group mutators
      */
@@ -367,31 +305,17 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             512
         );
 
-        $this->assertAttributeEquals(
-            $expectedAlgorithm,
-            'keyAlgorithm',
-            $this->generator,
-            'Setting key algorithm failed.'
-        );
 
-        $this->assertAttributeEquals(
-            $expectedSize,
-            'keySize',
-            $this->generator,
-            'Setting key size failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keyAlgorithm');
+        $this->assertSame($expectedAlgorithm, $value, 'Setting key algorithm failed.');
 
-        $this->assertAttributeEquals(
-            $expectedUsage,
-            'keyUsage',
-            $this->generator,
-            'Setting key algorithm and size changed key usage.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keySize');
+        $this->assertSame($expectedSize, $value, 'Setting key size failed.');
+
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keyUsage');
+        $this->assertSame($expectedUsage, $value, 'Setting key algorithm and size changed key usage.');
     }
 
-    // }}}
-    // {{{ testSetKeyParams_algorithm_size_and_usage()
-
     /**
      * @group mutators
      */
@@ -411,49 +335,34 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             | Crypt_GPG_SubKey::USAGE_ENCRYPT
         );
 
-        $this->assertAttributeEquals(
-            $expectedAlgorithm,
-            'keyAlgorithm',
-            $this->generator,
-            'Setting key algorithm failed.'
-        );
 
-        $this->assertAttributeEquals(
-            $expectedSize,
-            'keySize',
-            $this->generator,
-            'Setting key size failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keyAlgorithm');
+        $this->assertSame($expectedAlgorithm, $value, 'Setting key algorithm failed.');
 
-        $this->assertAttributeEquals(
-            $expectedUsage,
-            'keyUsage',
-            $this->generator,
-            'Setting key usage failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keySize');
+        $this->assertSame($expectedSize, $value, 'Setting key size failed.');
+
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'keyUsage');
+        $this->assertSame($expectedUsage, $value, 'Setting key algorithm and size changed key usage.');
     }
 
-    // }}}
-    // {{{ testSetKeyParams_invalid_algorithm()
-
     /**
      * @group mutators
-     * @expectedException Crypt_GPG_InvalidKeyParamsException
      */
     public function testSetKeyParams_invalid_algorithm()
     {
+        $this->expectException('Crypt_GPG_InvalidKeyParamsException');
+
         $this->generator->setKeyParams(Crypt_GPG_SubKey::ALGORITHM_ELGAMAL_ENC);
     }
 
-    // }}}
-    // {{{ testSetKeyParams_invalid_dsa_usage()
-
     /**
      * @group mutators
-     * @expectedException Crypt_GPG_InvalidKeyParamsException
      */
     public function testSetKeyParams_invalid_dsa_usage()
     {
+        $this->expectException('Crypt_GPG_InvalidKeyParamsException');
+
         $this->generator->setKeyParams(
             Crypt_GPG_SubKey::ALGORITHM_DSA,
             2048,
@@ -461,9 +370,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-    // {{{ testSetSubKeyParams_algorithm()
-
     /**
      * @group mutators
      */
@@ -477,31 +383,16 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             Crypt_GPG_SubKey::ALGORITHM_ELGAMAL_ENC_SGN
         );
 
-        $this->assertAttributeEquals(
-            $expectedAlgorithm,
-            'subKeyAlgorithm',
-            $this->generator,
-            'Setting sub-key algorithm failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeyAlgorithm');
+        $this->assertSame($expectedAlgorithm, $value, 'Setting sub-key algorithm failed.');
 
-        $this->assertAttributeEquals(
-            $expectedSize,
-            'subKeySize',
-            $this->generator,
-            'Setting sub-key algorithm changed key size.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeySize');
+        $this->assertSame($expectedSize, $value, 'Setting sub-key algorithm changed key size.');
 
-        $this->assertAttributeEquals(
-            $expectedUsage,
-            'subKeyUsage',
-            $this->generator,
-            'Setting sub-key algorithm changed key usage.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeyUsage');
+        $this->assertSame($expectedUsage, $value, 'Setting sub-key algorithm changed key usage.');
     }
 
-    // }}}
-    // {{{ testSetSubKeyParams_algorithm_and_size()
-
     /**
      * @group mutators
      */
@@ -516,31 +407,16 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             1024
         );
 
-        $this->assertAttributeEquals(
-            $expectedAlgorithm,
-            'subKeyAlgorithm',
-            $this->generator,
-            'Setting sub-key algorithm failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeyAlgorithm');
+        $this->assertSame($expectedAlgorithm, $value, 'Setting sub-key algorithm failed.');
 
-        $this->assertAttributeEquals(
-            $expectedSize,
-            'subKeySize',
-            $this->generator,
-            'Setting sub-key size failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeySize');
+        $this->assertSame($expectedSize, $value, 'Setting sub-key algorithm changed key size.');
 
-        $this->assertAttributeEquals(
-            $expectedUsage,
-            'subKeyUsage',
-            $this->generator,
-            'Setting sub-key algorithm and size changed key usage.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeyUsage');
+        $this->assertSame($expectedUsage, $value, 'Setting sub-key algorithm changed key usage.');
     }
 
-    // }}}
-    // {{{ testSetSubKeyParams_algorithm_size_and_usage()
-
     /**
      * @group mutators
      */
@@ -558,37 +434,23 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             | Crypt_GPG_SubKey::USAGE_ENCRYPT
         );
 
-        $this->assertAttributeEquals(
-            $expectedAlgorithm,
-            'subKeyAlgorithm',
-            $this->generator,
-            'Setting sub-key algorithm failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeyAlgorithm');
+        $this->assertSame($expectedAlgorithm, $value, 'Setting sub-key algorithm failed.');
 
-        $this->assertAttributeEquals(
-            $expectedSize,
-            'subKeySize',
-            $this->generator,
-            'Setting sub-key size failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeySize');
+        $this->assertSame($expectedSize, $value, 'Setting sub-key algorithm changed key size.');
 
-        $this->assertAttributeEquals(
-            $expectedUsage,
-            'subKeyUsage',
-            $this->generator,
-            'Setting sub-key usage failed.'
-        );
+        $value = $this->getPropertyValue('Crypt_GPG_KeyGenerator', $this->generator, 'subKeyUsage');
+        $this->assertSame($expectedUsage, $value, 'Setting sub-key algorithm changed key usage.');
     }
 
-    // }}}
-    // {{{ testSetSubKeyParams_invalid_elgamal_usage()
-
     /**
      * @group mutators
-     * @expectedException Crypt_GPG_InvalidKeyParamsException
      */
     public function testSetSubKeyParams_invalid_elgamal_usage()
     {
+        $this->expectException('Crypt_GPG_InvalidKeyParamsException');
+
         $this->generator->setSubKeyParams(
             Crypt_GPG_SubKey::ALGORITHM_ELGAMAL_ENC,
             2048,
@@ -596,15 +458,13 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-    // {{{ testSetSubKeyParams_invalid_dsa_usage()
-
     /**
      * @group mutators
-     * @expectedException Crypt_GPG_InvalidKeyParamsException
      */
     public function testSetSubKeyParams_invalid_dsa_usage()
     {
+        $this->expectException('Crypt_GPG_InvalidKeyParamsException');
+
         $this->generator->setSubKeyParams(
             Crypt_GPG_SubKey::ALGORITHM_DSA,
             2048,
@@ -612,11 +472,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         );
     }
 
-    // }}}
-
-    // generate key tests
-    // {{{ testGenerateKeyWithName()
-
     /**
      * @group generate-key
      */
@@ -661,9 +516,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $this->assertKeyEquals($expectedKey, $key);
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithNameAndEmail()
-
     /**
      * @group generate-key
      */
@@ -712,9 +564,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $this->assertKeyEquals($expectedKey, $key);
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithNameEmailAndComment()
-
     /**
      * @group generate-key
      */
@@ -765,9 +614,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $this->assertKeyEquals($expectedKey, $key);
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithUserId()
-
     /**
      * @group generate-key
      */
@@ -817,9 +663,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $this->assertKeyEquals($expectedKey, $key);
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithPassphrase()
-
     /**
      * @group generate-key
      */
@@ -869,9 +712,6 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $this->assertKeyEquals($expectedKey, $key);
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithExpirationDate()
-
     /**
      * @group generate-key
      */
@@ -923,15 +763,13 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
         $this->assertKeyEquals($expectedKey, $key);
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithInvalidPrimaryKeyAlgorithm()
-
     /**
      * @group generate-key
-     * @expectedException Crypt_GPG_InvalidKeyParamsException
      */
     public function testGenerateKeyWithInvalidPrimaryKeyAlgorithm()
     {
+        $this->expectException('Crypt_GPG_InvalidKeyParamsException');
+
         if (!$this->config['enable-key-generation']) {
             $this->markTestSkipped(
                 'Key generation tests are disabled. To run key generation '
@@ -949,15 +787,13 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
             );
     }
 
-    // }}}
-    // {{{ testGenerateKeyWithInvalidSubKeyAlgorithm()
-
     /**
      * @group generate-key
-     * @expectedException Crypt_GPG_InvalidKeyParamsException
      */
     public function testGenerateKeyWithInvalidSubKeyAlgorithm()
     {
+        $this->expectException('Crypt_GPG_InvalidKeyParamsException');
+
         if (!$this->config['enable-key-generation']) {
             $this->markTestSkipped(
                 'Key generation tests are disabled. To run key generation '
@@ -974,8 +810,4 @@ class KeyGeneratorTestCase extends Crypt_GPG_TestCase
                 )
             );
     }
-
-    // }}}
 }
-
-?>
