@@ -77,34 +77,28 @@ require_once 'Crypt/GPG/Signature.php';
  */
 abstract class Crypt_GPG_TestCase extends PHPUnit\Framework\TestCase
 {
-    // {{{ class constants
-
     const HOMEDIR = 'test-keychain';
-
     const TEMPDIR = 'temp-files';
-
     const DATADIR = 'data-files';
 
-    // }}}
-    // {{{ protected properties
-
     protected $gpg;
 
-    // }}}
-    // {{{ getOptions()
-
     protected function getOptions()
     {
+        $debugFunction = function ($text) {
+            file_put_contents(__DIR__ . '/debug.log', $text . "\n", FILE_APPEND);
+        };
+
         $config = array(
             'homedir' => __DIR__ . '/' . self::HOMEDIR,
-//            'binary' => '/usr/bin/gpg2',
-//            'agent'  => '/usr/bin/gpg-agent',
-//            'gpgconf'  => '/usr/local/bin/gpgconf',
-//            'cipher-algo' => 'AES256',
-//            'digest-algo' => 'SHA512',
-//            'compress-algo' => 'zip',
-//            'debug'  => true,
-//            'options' => array(),
+            // 'binary' => '/usr/bin/gpg2',
+            // 'agent'  => '/usr/bin/gpg-agent',
+            // 'gpgconf'  => '/usr/local/bin/gpgconf',
+            // 'cipher-algo' => 'AES256',
+            // 'digest-algo' => 'SHA512',
+            // 'compress-algo' => 'zip',
+            'debug'  => $debugFunction,
+            // 'options' => array(),
         );
 
         if ($binary = getenv('TESTS_GPG_BINARY')) {
@@ -114,19 +108,14 @@ abstract class Crypt_GPG_TestCase extends PHPUnit\Framework\TestCase
         return $config;
     }
 
-    // }}}
-
-    // set up
-    // {{{ setUp()
-
-    public function setUp()
+    public function setUp(): void
     {
         // load test configuration file if it exists
         $configFilename = __DIR__ . '/config.php';
         if (file_exists($configFilename)) {
             include $configFilename;
 
-            if (   !isset($GLOBALS['Crypt_GPG_Unittest_Config'])
+            if (!isset($GLOBALS['Crypt_GPG_Unittest_Config'])
                 || !is_array($GLOBALS['Crypt_GPG_Unittest_Config'])
             ) {
                 $this->markTestSkipped(
@@ -153,9 +142,6 @@ abstract class Crypt_GPG_TestCase extends PHPUnit\Framework\TestCase
         $this->gpg = new Crypt_GPG($this->getOptions());
     }
 
-    // }}}
-    // {{{ _setUpKeyring()
-
     private function _setUpKeyring()
     {
         // {{{ pubring data
@@ -547,15 +533,11 @@ TEXT;
         fclose($trustdb);
 
         $randomSeed = fopen($this->getKeyringFilename('random_seed'), 'wb');
-        fwrite($randomSeed, base64_decode(
-            str_replace("\n", '', $randomSeedData)));
+        fwrite($randomSeed, base64_decode(str_replace("\n", '', $randomSeedData)));
 
         fclose($randomSeed);
     }
 
-    // }}}
-    // {{{ _setUpTempdir()
-
     private function _setUpTempdir()
     {
         $directoryName = __DIR__ . '/' . self::TEMPDIR;
@@ -564,10 +546,7 @@ TEXT;
         }
     }
 
-    // }}}
-    // {{{ tearDown()
-
-    public function tearDown()
+    public function tearDown(): void
     {
         unset($this->gpg);
 
@@ -575,9 +554,6 @@ TEXT;
         $this->_tearDownTempdir();
     }
 
-    // }}}
-    // {{{ _tearDownKeyring()
-
     private function _tearDownKeyring()
     {
         $dirnames = array(
@@ -615,9 +591,6 @@ TEXT;
         rmdir($homedir);
     }
 
-    // }}}
-    // {{{ _tearDownTempdir()
-
     private function _tearDownTempdir()
     {
         $directoryName = __DIR__ . '/' . self::TEMPDIR;
@@ -640,52 +613,28 @@ TEXT;
         rmdir($directoryName);
     }
 
-    // }}}
-    // {{{ getMd5Sum()
-
     protected function getMd5Sum($filename)
     {
-        if (`which md5sum` == '') {
-            $this->markTestSkipped('md5sum not available. Cannot verify ' .
-                'files for file tests.');
-        }
-
-        $sum = explode(' ', `md5sum $filename`);
-        $sum = $sum[0];
-        return $sum;
+        return md5_file($filename);
     }
 
-    // }}}
-    // {{{ getKeyringFilename()
-
     protected function getKeyringFilename($filename)
     {
         return __DIR__ . '/'. self::HOMEDIR . '/' . $filename;
     }
 
-    // }}}
-    // {{{ getDataFilename()
-
     protected function getDataFilename($filename)
     {
         return __DIR__ . '/'. self::DATADIR . '/' . $filename;
     }
 
-    // }}}
-    // {{{ getTempFilename()
-
     protected function getTempFilename($filename)
     {
         return __DIR__ . '/' . self::TEMPDIR . '/' . $filename;
     }
 
-    // }}}
-    // {{{ assertDecryptAndVerifyResultsEquals()
-
-    protected function assertDecryptAndVerifyResultsEquals(
-        array $expected,
-        array $actual
-    ) {
+    protected function assertDecryptAndVerifyResultsEquals(array $expected, array $actual)
+    {
         $this->assertEquals(
             count($expected),
             count($actual),
@@ -728,13 +677,8 @@ TEXT;
         );
     }
 
-    // }}}
-    // {{{ assertSignaturesEquals()
-
-    protected function assertSignaturesEquals(
-        array $expected,
-        array $actual
-    ) {
+    protected function assertSignaturesEquals(array $expected, array $actual)
+    {
         $this->assertEquals(
             count($expected),
             count($actual),
@@ -746,9 +690,6 @@ TEXT;
         }
     }
 
-    // }}}
-    // {{{ assertSignatureEquals()
-
     protected function assertSignatureEquals(
         Crypt_GPG_Signature $expected,
         Crypt_GPG_Signature $actual
@@ -800,7 +741,22 @@ TEXT;
         );
     }
 
-    // }}}
-}
+    protected function getPropertyValue($class, $object, $property)
+    {
+        $reflectionClass = new ReflectionClass($class);
 
-?>
+        $prop = $reflectionClass->getProperty($property);
+
+        $prop->setAccessible(true);
+
+        return $prop->getValue($object);
+    }
+
+    /**
+     * This method is used only when we run tests under PHPUnit 4.8 via Github Actions
+     */
+    protected function setExpectedExceptionMessage($message)
+    {
+        // do nothing
+    }
+}
